@@ -11,13 +11,9 @@ import os
 import sys
 sys.path.insert(0, os.path.abspath('..'))
 
-def foo():
-    print(os.getcwd())
-    print(os.path.abspath(__file__).replace(__file__, ''))
-
 def generate_html(template_config):
-    template_path = os.path.abspath(__file__).replace(__file__, '') + 'static/templates_auto/0/index.html'
-    print(template_path)
+    template_path = os.path.abspath(__file__)
+    template_path = template_path.replace(template_path.split('/')[-1], '') + 'static/templates_auto/0/index.html'
     with open(template_path, 'r') as fp:
         template_str = Template(fp.read())
         s = template_str.render(
@@ -26,7 +22,8 @@ def generate_html(template_config):
         return s
 
 def generate_css(template_config):
-    template_path = os.path.abspath(__file__).replace(__file__, '') + 'static/templates_auto/0/main.css'
+    template_path = os.path.abspath(__file__)
+    template_path = template_path.replace(template_path.split('/')[-1], '') + 'static/templates_auto/0/main.css'
     with open(template_path, 'r') as fp:
         template_str = Template(fp.read())
         s = template_str.render(
@@ -47,6 +44,7 @@ def handle_blur(template_config):
         base_image = Image.open(template_config['outer_image'])
         blur_image = base_image.filter(ImageFilter.GaussianBlur(template_config['outer_image_blur']))
 
+        template_config['tmp_outer_image'] = template_config['outer_image']
         template_config['outer_image'] = 'tmp_outer_image_blur.png'# + template_config['outer_image'].split('.')[-1]
         blur_image.save(template_config['outer_image'])
 
@@ -137,7 +135,10 @@ def get_image_config(image_path):
     hidden_message = json.loads(lsb.reveal(image_path).replace('\'', '\"').replace(': None,', ': null,').replace(': nan,', ': null,'))
     return hidden_message
 
-def generate_definitions_from_csv(csv_path, list_of_indexes=None):
+def generate_definitions_from_csv(csv_path, output_folder=os.getcwd(), list_of_indexes=None):
+    if output_folder[-1] == '/':
+        output_folder = output_folder[:-1]        
+
     # create the pointer to the template config structure
     template_config = {}
 
@@ -151,7 +152,7 @@ def generate_definitions_from_csv(csv_path, list_of_indexes=None):
             update_template_config(dataframe, int(i), template_config)
 
             # generate definition i
-            generate_definition_from_json(template_config, f'output/out{i}.png')
+            generate_definition_from_json(template_config, f'{output_folder}/out{i}.png')
     else:
         # generate all the definitions in the csv
         for i in range(len(dataframe)):
@@ -159,4 +160,4 @@ def generate_definitions_from_csv(csv_path, list_of_indexes=None):
             update_template_config(dataframe, i, template_config)
 
             # generate definition i
-            generate_definition_from_json(template_config, f'output/out{i}.png')
\ No newline at end of file
+            generate_definition_from_json(template_config, f'{output_folder}/out{i}.png')
\ No newline at end of file
