@@ -7,7 +7,7 @@ if __name__ == '__main__':
         if len(sys.argv) == 2:
             generate_definitions_from_csv(sys.argv[1])
         elif len(sys.argv) > 2:
-            generate_definitions_from_csv(sys.argv[1], list_of_indexes=sys.argv[2:])
+            generate_definitions_from_csv(sys.argv[1], 'output/', list_of_indexes=sys.argv[2:])
 
     if sys.argv[1].split('.')[-1] == 'json':
         with open(sys.argv[1]) as fp:
